#
# spec file for package python-discid
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Johannes Dewender <novell@JonnyJD.net>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define modname discid

Name:           python-%{modname}
Version:        1.1.0
Release:        3.2
Summary:        Python binding of Libdiscid
License:        LGPL-3.0+
Group:          Development/Libraries/Python
Url:            https://python-discid.readthedocs.org/
Source:         https://pypi.python.org/packages/source/d/%{modname}/%{modname}-%{version}.tar.gz
# no automatic requires since libdiscid is not linked
Requires:       libdiscid0 >= 0.2.2
BuildRequires:  libdiscid0 >= 0.2.2
BuildRequires:  python-devel >= 2.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Python-discid implements Python bindings for MusicBrainz Libdiscid.

Libdiscid's main purpose is the calculation of an identifier of audio
discs (disc id) to use for the MusicBrainz database.

That identifier is calculated from the TOC of the disc, similar to the
freeDB CDDB identifier. Libdiscid can calculate MusicBrainz Disc IDs and
freeDB Disc IDs.
Additionally the MCN of the disc and ISRCs from the tracks can be extracted.

This module is a close binding that offloads all relevant data
storage and calculation to Libdiscid. On the other hand it gives a
pythonic API and uses objects and exceptions.

%prep
%setup -q -n discid-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=$RPM_BUILD_ROOT --record=INSTALLED_FILES
chmod a-x examples.py

%files -f INSTALLED_FILES
%defattr(-,root,root)
%dir %{python_sitelib}/*
%doc COPYING COPYING.LESSER CHANGES.rst examples.py

%changelog
* Sun Jul 24 2016 rpm@fthiessen.de
- Update to current upstream release 1.1.0
* Mon Jul  4 2016 jengelh@inai.de
- Request libdiscid0 since the code looks for exactly .so.0.
- Remove redundant %%clean section.
* Thu Jun 27 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 1.0.2
  * No code changes compared to 1.0.0 release
* Tue Jun 25 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 1.0.0
  * DEFAULT_DEVICE is now get_default_device()
  * Disc.submission_url doesn’t point to a redirect now
  * fix: seconds are now rounded the same as on MB server (0.5->up)
* Fri Apr 26 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.5.0
  * feature: add Disc.mcn and Track.isrc
  * feature: add LIBDISCID_VERSION_STRING
  * feature: add Disc.seconds, Track.seconds
  and aliases Disc.length and Track.sectors
  * move read and put to module level
  * changed parameters for put() to include extra `sectors` and add TOCError
  * rename DiscId to Disc
  * fix: move track attributes to Track
  * fix: only have "real" tracks in the list(s) (0 not special)
  * fix: only read the requested features from disc (sparse)
  * fix: remove DiscId.webservice_url (deprecated)
  * fix: detect the version of libdiscid 0.3.0 also in lib64 installations
* Wed Apr 10 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.4.0
  * feature: added FEATURES_IMPLEMENTED, DiscId.track_lengths,
  DiscId.webservice_url and DiscId.freedb_id
  * feature: disc access test suite
* Mon Mar 11 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.3.0
  * feature: add FEATURES list
  * feature: DiscId.put, DiscId.track_offsets, DiscId.sectors,
  DiscId.first_track_num, DiscId.last_track_num
  * fix: prefer libdiscid in current directory
  * fix: find libdiscid in current folder (Linux/Unix)
* Wed Feb 20 2013 Johannes Dewender <novell@JonnyJD.net>
- Add version requirements
* Fri Feb  1 2013 Johannes Dewender <novell@JonnyJD.net>
- Add basic doc files to package (license, changes, example)
* Wed Jan 30 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.2.1
  * fixed Python 3.2 bug in the tests (upstream #9)
* Wed Jan 30 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.2.0
  * API change from DiscId.get_id to DiscId.id
  * added DEFAULT_DEVICE as a module constant
  * added DiscId.submission_url
* Mon Jan 14 2013 Johannes Dewender <novell@JonnyJD.net>
- Initial release (0.1.0)
